

#include "rtc_test.h"

//*****************************************************************************
//
//! UART0, connected to the Stellaris Virtual Serial Port and running at
//! 115,200, 8-N-1, is used to display messages from this application.
//
//*****************************************************************************


//*****************************************************************************
//
// The error routine that is called if the driver library encounters an error.
//
//*****************************************************************************
#ifdef DEBUG
void
__error__(char *pcFilename, unsigned long ulLine)
{
}
#endif

//*****************************************************************************
//
// Print "RTC DS1307!" to the UART on the Stellaris evaluation board.
//
//*****************************************************************************

const  char *wdname[7] = {"Son", "Mon", "Die", "Mit", "Don", "Fre", "Sam",};// Anzeige Datum


int main(void)
{
    volatile unsigned long ulLoop;
    ROM_FPULazyStackingEnable();
    ROM_SysCtlClockSet(SYSCTL_SYSDIV_4 | SYSCTL_USE_PLL | SYSCTL_XTAL_16MHZ | SYSCTL_OSC_MAIN); // 50Mhz
    ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOF);
    ROM_GPIOPinTypeGPIOOutput(GPIO_PORTF_BASE, GPIO_PIN_2);

    // Initialize the UART.
    ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA);
    ROM_GPIOPinConfigure(GPIO_PA0_U0RX);
    ROM_GPIOPinConfigure(GPIO_PA1_U0TX);
    ROM_GPIOPinTypeUART(GPIO_PORTA_BASE, GPIO_PIN_0 | GPIO_PIN_1);
    UARTStdioInit(0);


    // I2C1 init
	ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_I2C1);
    ROM_GPIOPinConfigure(GPIO_PA7_I2C1SDA);
	ROM_GPIOPinConfigure(GPIO_PA6_I2C1SCL);
    ROM_GPIOPinTypeI2C(GPIO_PORTA_BASE, GPIO_PIN_7);
	GPIOPinTypeI2CSCL(GPIO_PORTA_BASE, GPIO_PIN_6);
  	I2CMasterInitExpClk(I2C1_MASTER_BASE, SysCtlClockGet(), false);

    UARTprintf("RTCInit, ok\n");

   // set_rtc_hand();

    while(1)
    {
    	delay_ms(250);delay_ms(250);
    	lesen_rtc();

    	delay_ms(250);delay_ms(250);
    	ausgabe_display_start();
    }
}

void ausgabe_display_start(void)
{
	UARTprintf("%s, %02d.%02d.%d\r\n",(char*)wdname[(rtc_buf.w_tag-1)],rtc_buf.tag,rtc_buf.monat,(rtc_buf.jahr+2000));
	UARTprintf("%02d:%02d:%02d\r\n",rtc_buf.stunde,rtc_buf.minute,rtc_buf.sekunde);

}

void set_rtc_hand(void)
{
	rtc_buf.buffer[0]= 0x00;			//set seconds
	rtc_buf.buffer[1]= 0x35; 			//set minutes
	rtc_buf.buffer[2]= 0x12;			//set hours
	rtc_buf.buffer[3]= 0x04; 			//set day
	rtc_buf.buffer[4]= 0x28;			//set date
	rtc_buf.buffer[5]= 0x10; 			//set month
	rtc_buf.buffer[6]= 0x13;			//set year

	I2CWriteData(I2C1_MASTER_BASE, SLAVE_ADDRESS, 0, rtc_buf.buffer, 7);
}


void lesen_rtc(void)
{

		I2CReadData(I2C1_MASTER_BASE, SLAVE_ADDRESS, 0x0, rtc_buf.write_buffer, 19);

		rtc_buf.sekunde = rtc_bcd_to_hex(rtc_buf.write_buffer[0x00]);		//Sekunde
		rtc_buf.minute  = rtc_bcd_to_hex(rtc_buf.write_buffer[0x01]);		//Minute
		rtc_buf.stunde  = rtc_bcd_to_hex(rtc_buf.write_buffer[0x02]);		//Stunde
		rtc_buf.w_tag=rtc_bcd_to_hex(rtc_buf.write_buffer[0x03]);			//W-Tag
		rtc_buf.tag=rtc_bcd_to_hex(rtc_buf.write_buffer[0x04]);				//Tag
		rtc_buf.monat=rtc_bcd_to_hex(rtc_buf.write_buffer[0x05]);			//Monat
		rtc_buf.jahr=rtc_bcd_to_hex(rtc_buf.write_buffer[0x06]);			//Jahr
		rtc_buf.sekunde_al1 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x07]);	//Alarm1 Sekunde  Sonnenaufgang
		rtc_buf.minute_al1 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x08]);	//Alarm1 Minute
		rtc_buf.stunde_al1 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x09]);	//Alarm1 Stunde
		rtc_buf.tag_al1 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x0A]);		//Alarm1 Tag
		rtc_buf.minute_al2 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x0B]);	//Alarm2 Minute  Sonnenuntergang
		rtc_buf.stunde_al2 = rtc_bcd_to_hex(rtc_buf.write_buffer[0x0C]);	//Alarm2 Stunde
		rtc_buf.tag_al2  =rtc_bcd_to_hex(rtc_buf.write_buffer[0x0D]);		//Alarm2 Tag
		rtc_buf.control = rtc_buf.write_buffer[0x0E];
		rtc_buf.control_status = rtc_buf.write_buffer[0x0F];
		rtc_buf.offset = rtc_buf.write_buffer[0x10];
		rtc_buf.temp_h = rtc_buf.write_buffer[0x11];			// low 0 bis 1
		rtc_buf.temp_l = rtc_buf.write_buffer[0x12];			// high-byte 0 bis 7


			// MSB has a sign bit at the top
			if (rtc_buf.temp_h & 0x80)
			{
				rtc_buf.nullgrad = 1; // fr Ausgabe 1 = Minus (-) 0 = Plus (+)
			}
				// then the rest of the MSB is just as-is
				rtc_buf.temp_h = (rtc_buf.temp_h & 0x7f);
				// fraction is the upper 2 bits, covering 1/4 degrees
				rtc_buf.temp_l = (rtc_buf.temp_l >> 6) * 25;


}

char rtc_bcd_to_hex(char v)// rtc_bcd_to_hex: wandelt BCD zu HEX Zahl um
{
	char n;

	n=v;
	n=n & 0xF0;
	n=n/16;
	v =v & 0x0F;
	n=n*10+v;
	return(n);
}


char rtc_hex_to_bcd(char v)// rtc_hex_to_bcd: wandelt HEX zu BCD Zahl um
{
	char n;

	n=v;
	n=n/10;
	n=n*16;
	v =v % 10;
	n=n+v;
	return(n);
}
